"""VMFinder - A libvirt-based VM management tool for paper reproduction."""

__version__ = "0.2.0"
__author__ = "wheatfox"
__author_email__ = "wheatfox17@icloud.com"
__url__ = "https://github.com/enkerewpo/vmfinder"
__description__ = "A libvirt-based VM management tool"
__copyright__ = "Copyright 2025 wheatfox"
